@@ -13,7 +13,6 @@ __all__ = [
 
 import pygame
 import pygame_menu
-import pygame_menu.controls as ctrl
 import pygame_menu.events as _events
 import re
 import webbrowser
@@ -204,9 +203,9 @@ class Button(Widget):
 
             # User applies with key
             if event.type == pygame.KEYDOWN and self._keyboard_enabled and \
-                    event.key == ctrl.KEY_APPLY or \
+                    self._ctrl.apply(event, self) or \
                     event.type == pygame.JOYBUTTONDOWN and self._joystick_enabled and \
-                    event.button == ctrl.JOY_BUTTON_SELECT:
+                    self._ctrl.joy_select(event, self):
                 if self.to_menu:
                     self._sound.play_open_menu()
                 else:
