@@ -27,7 +27,6 @@ __all__ = [
 
 import pygame
 import pygame_menu
-import pygame_menu.controls as ctrl
 
 from abc import ABC
 from pygame_menu.locals import FINGERUP
@@ -454,22 +453,22 @@ class Selector(Widget):
             joy_button_down = self._joystick_enabled and event.type == pygame.JOYBUTTONDOWN
 
             # Left button
-            if keydown and event.key == ctrl.KEY_LEFT or \
-                    joy_hatmotion and event.value == ctrl.JOY_LEFT or \
-                    joy_axismotion and event.axis == ctrl.JOY_AXIS_X and event.value < ctrl.JOY_DEADZONE:
+            if keydown and self._ctrl.left(event, self) or \
+                    joy_hatmotion and self._ctrl.joy_left(event, self) or \
+                    joy_axismotion and self._ctrl.joy_axis_x_left(event, self):
                 self._left()
                 return True
 
             # Right button
-            elif keydown and event.key == ctrl.KEY_RIGHT or \
-                    joy_hatmotion and event.value == ctrl.JOY_RIGHT or \
-                    joy_axismotion and event.axis == ctrl.JOY_AXIS_X and event.value > -ctrl.JOY_DEADZONE:
+            elif keydown and self._ctrl.right(event, self) or \
+                    joy_hatmotion and self._ctrl.joy_right(event, self) or \
+                    joy_axismotion and self._ctrl.joy_axis_x_right(event, self):
                 self._right()
                 return True
 
             # Press enter
-            elif keydown and event.key == ctrl.KEY_APPLY or \
-                    joy_button_down and event.button == ctrl.JOY_BUTTON_SELECT:
+            elif keydown and self._ctrl.apply(event, self) or \
+                    joy_button_down and self._ctrl.joy_select(event, self):
                 self._sound.play_key_add()
                 self.apply(*self._items[self._index][1:])
                 return True
@@ -605,7 +604,7 @@ class SelectorManager(AbstractWidgetManager, ABC):
         :param title: Title of the selector
         :param items: Item list of the selector; format ``[('Item1', a, b, c...), ('Item2', d, e, f...)]``
         :param default: Index of default item to display
-        :param onchange: Callback executed when when changing the selector
+        :param onchange: Callback executed when changing the selector
         :param onreturn: Callback executed when pressing return button
         :param onselect: Callback executed when selecting the widget
         :param selector_id: ID of the selector
