@@ -13,7 +13,6 @@ __all__ = [
 
 import pygame
 import pygame_menu
-import pygame_menu.controls as ctrl
 
 from abc import ABC
 from pygame_menu.font import FontType, assert_font
@@ -417,23 +416,23 @@ class ToggleSwitch(Widget):
             joy_axismotion = self._joystick_enabled and event.type == pygame.JOYAXISMOTION
 
             # Left button
-            if keydown and event.key == ctrl.KEY_LEFT or \
-                    joy_hatmotion and event.value == ctrl.JOY_LEFT or \
-                    joy_axismotion and event.axis == ctrl.JOY_AXIS_X and event.value < ctrl.JOY_DEADZONE:
+            if keydown and self._ctrl.left(event, self) or \
+                    joy_hatmotion and self._ctrl.joy_left(event, self) or \
+                    joy_axismotion and self._ctrl.joy_axis_x_left(event, self):
                 self._left()
                 return True
 
             # Right button
-            elif keydown and event.key == ctrl.KEY_RIGHT or \
-                    joy_hatmotion and event.value == ctrl.JOY_RIGHT or \
-                    joy_axismotion and event.axis == ctrl.JOY_AXIS_X and event.value > -ctrl.JOY_DEADZONE:
+            elif keydown and self._ctrl.right(event, self) or \
+                    joy_hatmotion and self._ctrl.joy_right(event, self) or \
+                    joy_axismotion and self._ctrl.joy_axis_x_right(event, self):
                 self._right()
                 return True
 
             # Press enter
-            elif keydown and event.key == ctrl.KEY_APPLY and self._total_states == 2 or \
+            elif keydown and self._ctrl.apply(event, self) and self._total_states == 2 or \
                     event.type == pygame.JOYBUTTONDOWN and self._joystick_enabled and \
-                    event.button == ctrl.JOY_BUTTON_SELECT and self._total_states == 2:
+                    self._ctrl.joy_select(event, self) and self._total_states == 2:
                 self._sound.play_key_add()
                 self._state = int(not self._state)
                 self.change()
@@ -589,7 +588,7 @@ class ToggleSwitchManager(AbstractWidgetManager, ABC):
 
         :param title: Title of the toggle switch
         :param default: Default state index of the switch; it can be ``0 (False)`` or ``1 (True)``
-        :param onchange: Callback executed when when changing the state of the toggle switch
+        :param onchange: Callback executed when changing the state of the toggle switch
         :param onselect: Callback executed when selecting the widget
         :param toggleswitch_id: Widget ID
         :param single_click: Changes the state of the switch with 1 click instead of finding the closest position
